Checkbox Unit Types
===================

Checkbox execution is governed by Units.

All units follow :ref:`rfc822`.

.. toctree::
    :maxdepth: 2
    
    job.rst
    test-plan.rst
    category.rst
    resource.rst
    template.rst
    exporter.rst
    manifest-entry.rst
    packaging-meta-data.rst
    rfc822.rst
